Stan Math Library: stan::VectorBuilderHelper< T1, true, false > Class Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | Public Member Functions | List of all members
stan::VectorBuilderHelper< T1, true, false > Class Template Reference

`#include <VectorBuilderHelper.hpp>`

## Public Types
typedef T1 | type

## Public Member Functions
| VectorBuilderHelper (size_t)
T1 & | operator[] (size_t)
type & | data ()

## Detailed Description

### template<typename T1>
class stan::VectorBuilderHelper< T1, true, false >

Definition at line 41 of file VectorBuilderHelper.hpp.

## Member Typedef Documentation

template<typename T1 >

typedef T1 stan::VectorBuilderHelper< T1, true, false >::type

Definition at line 50 of file VectorBuilderHelper.hpp.

## Constructor & Destructor Documentation

template<typename T1 >

stan::VectorBuilderHelper< T1, true, false >::VectorBuilderHelper | ( | size_t |  | ) |
| inlineexplicit

Definition at line 45 of file VectorBuilderHelper.hpp.

## Member Function Documentation

template<typename T1 >

type& stan::VectorBuilderHelper< T1, true, false >::data | ( |  | ) |
| inline

Definition at line 52 of file VectorBuilderHelper.hpp.

template<typename T1 >

T1& stan::VectorBuilderHelper< T1, true, false >::operator[] | ( | size_t |  | ) |
| inline

Definition at line 46 of file VectorBuilderHelper.hpp.

The documentation for this class was generated from the following file:

- stan/math/prim/scal/meta/VectorBuilderHelper.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.